import type { IDS, PageQuery, PageResult } from '#/api/common';
import type { FixtureImportParam, FixtureVO } from '#/api/eims/fixture/model';

import { commonExport, ContentTypeEnum } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  fixtureExport = '/eims/fixture/export',
  fixtureImport = '/eims/fixture/importData',
  fixtureImportTemplate = '/eims/fixture/importTemplate',
  fixtureList = '/eims/fixture/list',
  root = '/eims/fixture'
}

/**
 * 查询【工具台账】列表
 * @param query
 * @returns {*}
 */

export function listFixture(params?: PageQuery) {
  return requestClient.get<PageResult<FixtureVO>>(Api.fixtureList, { params });
}

/**
 * 查询【工具台账】详细
 * @param fixId
 */
export function getFixture(fixId: any) {
  return requestClient.get<FixtureVO>(`${Api.root}/${fixId}`);
}

/**
 * 新增【工具台账】
 * @param data
 */
export function addFixture(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改【工具台账】
 * @param data
 */
export function updateFixture(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除【工具台账】
 * @param fixIds
 */
export function delFixture(fixIds: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${fixIds}`);
}

/**
 * 导出【工具台账】
 * @param data
 */
export function fixtureExport(data: any) {
  return commonExport(Api.fixtureExport, data);
}

/**
 * 从excel导入设备
 * @param data
 * @returns void
 */
export function fixtureImportData(data: FixtureImportParam) {
  return requestClient.post<{ code: number; msg: string }>(Api.fixtureImport, data, {
    headers: {
      'Content-Type': ContentTypeEnum.FORM_DATA
    },
    isTransformResponse: false
  });
}

/**
 * 下载导入模板
 * @returns blob
 */
export function downloadImportTemplate() {
  return requestClient.post<Blob>(
    Api.fixtureImportTemplate,
    {},
    {
      isTransformResponse: false,
      responseType: 'blob'
    }
  );
}
